@@ -1,7 +1,8 @@
 
 #' Lists of research briefing topics, subtopics and types.
 #'
-#' Returns lists of research briefing topics, subtopics and types. These functions do not accept any arguments.
+#' Returns lists of research briefing topics, subtopics and types.
+#' These functions do not accept any arguments.
 #'
 #' @rdname research_briefings_lists
 #' @return A list with the different research topics/subtopics/types available.
@@ -10,9 +11,12 @@
 #'
 #' @section Member details functions:
 #' \describe{
-#' \item{research_topics_list}{A list with the different research topics available}
-#' \item{research_subtopics_list}{A list of Parliamentary Research Briefings topics}
-#' \item{research_types_list}{A list of types of Parliamentary Research Briefings}
+#' \item{research_topics_list}{A list with the different research
+#' topics available}
+#' \item{research_subtopics_list}{A list of Parliamentary Research
+#'  Briefings topics}
+#' \item{research_types_list}{A list of types of Parliamentary
+#' Research Briefings}
 #' }
 #' @examples  \dontrun{
 #' research_topics_list <- research_topics_list()
@@ -24,7 +28,8 @@
 
 research_topics_list <- function() {
 
-    x <- jsonlite::fromJSON("http://lda.data.parliament.uk/researchbriefingtopics.json?", flatten = TRUE)
+    x <- jsonlite::fromJSON(paste0(url_util, "researchbriefingtopics.json?"),
+                            flatten = TRUE)
 
     research_topics_list <- as.list(x$result$items$prefLabel._value)
 
@@ -43,7 +48,8 @@ hansard_research_topics_list <- research_topics_list
 #' @export
 research_subtopics_list <- function() {
 
-    x <- jsonlite::fromJSON("http://lda.data.parliament.uk/researchbriefingtopics.json?", flatten = TRUE)
+    x <- jsonlite::fromJSON(paste0(url_util, "researchbriefingtopics.json?"),
+                            flatten = TRUE)
 
     research_topics_list <- as.list(x$result$items$prefLabel._value)
 
@@ -53,7 +59,8 @@ research_subtopics_list <- function() {
 
         i <- utils::URLencode(i)
 
-        g <- jsonlite::fromJSON(paste0("http://lda.data.parliament.uk/researchbriefingsubtopics/", i, ".json?"), flatten = TRUE)
+        g <- jsonlite::fromJSON(paste0(url_util, "researchbriefingsubtopics/",
+            i, ".json?"), flatten = TRUE)
 
         i <- utils::URLdecode(i)
 
@@ -74,7 +81,7 @@ hansard_research_subtopics_list <- research_subtopics_list
 #' @export
 research_types_list <- function() {
 
-    x <- jsonlite::fromJSON("http://lda.data.parliament.uk/researchbriefingtypes.json?")
+    x <- jsonlite::fromJSON(paste0(url_util, "researchbriefingtypes.json?"))
 
     research_types_list <- as.list(x$result$items$prefLabel$`_value`)
 
