@@ -5,7 +5,10 @@ context("commons functions")
 test_that("commons functions return expected format", {
     skip_on_cran()
 
-    xcaq <- hansard_commons_answered_questions(answering_department = c('health','education'), answered_by = c(4019, 1542, 111), verbose=TRUE, start_date = '2017-02-01', end_date= '2017-06-18')
+    xcaq <- hansard_commons_answered_questions(
+      answering_department = c('health','education'),
+      answered_by = c(4019, 1542, 111), verbose=TRUE,
+      start_date = '2017-02-01', end_date= '2017-06-18')
     expect_length(xcaq, 10)
     expect_type(xcaq, "list")
     expect_true(tibble::is_tibble(xcaq))
@@ -13,17 +16,20 @@ test_that("commons functions return expected format", {
 
     # Divisions
 
-    xcd <- hansard_commons_divisions(division_id = 694163, summary = FALSE, verbose=TRUE)
+    xcd <- hansard_commons_divisions(division_id = 694163,
+                                     summary = FALSE, verbose=TRUE)
     expect_length(xcd, 7)
     expect_type(xcd, "list")
     expect_true(tibble::is_tibble(xcd))
 
-    xcds <- hansard_commons_divisions(division_id = 694163, summary = TRUE, verbose=TRUE)
+    xcds <- hansard_commons_divisions(division_id = 694163,
+                                      summary = TRUE, verbose=TRUE)
     expect_length(xcds, 13)
     expect_type(xcds, "list")
     expect_true(tibble::is_tibble(xcds))
 
-    xcdall <- hansard_commons_divisions(start_date = "2017-02-01", end_date = "2017-03-01", verbose=TRUE)
+    xcdall <- hansard_commons_divisions(start_date = "2017-02-01",
+                                        end_date = "2017-03-01", verbose=TRUE)
     expect_length(xcdall, 5)
     expect_type(xcdall, "list")
     expect_true(tibble::is_tibble(xcdall))
@@ -36,22 +42,30 @@ test_that("commons functions return expected format", {
     expect_equal(nrow(cdd), 5)
 
     ## Questions
-    xcoqt <- hansard_commons_oral_question_times(session = "2016/17", question_id = "685697", verbose=TRUE) #
+    xcoqt <- hansard_commons_oral_question_times(session = "2016/17",
+                                                 question_id = "685697",
+                                                 verbose=TRUE) #
     expect_length(xcoqt, 16)
     expect_type(xcoqt, "list")
     expect_true(tibble::is_tibble(xcoqt))
 
-    xcoqs <- hansard_commons_oral_question_times(session = "2015/16", verbose=TRUE)
+    xcoqs <- hansard_commons_oral_question_times(session = "2015/16",
+                                                 verbose=TRUE)
     expect_length(xcoqs, 15)
     expect_type(xcoqs, "list")
     expect_true(tibble::is_tibble(xcoqs))
 
-    xcoqe <- hansard_commons_oral_questions(mp_id=c(4019,4051,4588),answering_department = c('education', 'health'), verbose=TRUE, tidy_style = "period.case")
+    xcoqe <- hansard_commons_oral_questions(
+      mp_id=c(4019,4051,4588),
+      answering_department = c('education', 'health'),
+      verbose=TRUE, tidy_style = "period.case")
     expect_length(xcoqe, 24)
     expect_type(xcoqe, "list")
     expect_true(tibble::is_tibble(xcoqe))
 
-    xcwq <- hansard_commons_written_questions(mp_id=c(410,172), c('cabinet','home'), verbose=TRUE, start_date = '2017-02-01', end_date= '2017-03-18')
+    xcwq <- hansard_commons_written_questions(
+      mp_id=c(410,172), c('cabinet','home'), verbose=TRUE,
+      start_date = '2017-02-01', end_date= '2017-03-18')
     expect_length(xcwq, 12)
     expect_type(xcwq, "list")
     expect_true(tibble::is_tibble(xcwq))
@@ -64,7 +78,8 @@ test_that("commons functions return expected format", {
     expect_type(xcte, "list")
     expect_true(tibble::is_tibble(xcte))
 
-    xctec <- hansard_commons_terms(search = "estate", class = "ORG", verbose=TRUE)
+    xctec <- hansard_commons_terms(search = "estate",
+                                   class = "ORG", verbose=TRUE)
     expect_length(xctec, 19)
     expect_type(xctec, "list")
     expect_true(tibble::is_tibble(xctec))
